<?php

/**
 * @file
 * Provides the Consent Manager administration settings.
 */

/**
 * Consent Manager settings form.
 *
 * @param $form
 * @param $form_state
 *
 * @return array
 */
function consent_manager_settings($form, &$form_state) {
  $config = variable_get('consent_manager');
  $path = '/' . drupal_get_path('module', 'consent_manager');

  $form['consent_manager'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings'),
    '#collapsible' => FALSE,
    '#tree' => TRUE,
  );
  
  $form['consent_manager']['blocking_mode'] = array(
    '#type' => 'select',
    '#title' => t('Blocking mode'),
    '#options' => array(
      'automatic' => t('Automatic blocking'),
      'semi_automatic' => t('Semi-Automatic blocking'),
    ),
    '#default_value' => isset($config['blocking_mode']) ? $config['blocking_mode'] : 'semi_automatic',
    '#required' => TRUE,
  );
  
  $form['consent_manager']['cdid'] = array(
    '#type' => 'textfield',
    '#title' => t('Code-ID'),
    '#description' => t('If you don\'t yet have an Code-ID, please get in on <a href="@url" target="_blank">www.consentmanager.net</a>', array('@url' => 'https://www.consentmanager.net/client/codes.php')),
    '#default_value' => isset($config['cdid']) ? $config['cdid'] : '',
    '#required' => TRUE,
  );

  $form['consent_manager']['cdid_image'] = array(
    '#type' => 'html_tag',
    '#tag' => 'img',
    '#attributes' => array(
      'src' => $path . '/images/cmpcodeid.png',
      'width' => '500',
      'height' => 'auto',
    ),
  );

  $form['consent_manager']['host'] = array(
    '#type' => 'textfield',
    '#title' => t('Host'),
    '#description' => t('Leave blank to use the default value: %default_value. You need to specify the host name value only (without the protocol https://).', array('%default_value' => CONSENT_MANAGER_DEFAULT_HOST)),
    '#default_value' => isset($config['host']) ? $config['host'] : '',
  );

  $form['consent_manager']['host_image'] = array(
    '#type' => 'html_tag',
    '#tag' => 'img',
    '#attributes' => array(
      'src' => $path . '/images/cmphost.png',
      'width' => '500',
      'height' => 'auto',
    ),
  );

  $form['consent_manager']['cdn'] = array(
    '#type' => 'textfield',
    '#title' => t('CDN'),
    '#description' =>t('Leave blank to use the default value: %default_value. You need to specify the host name value only (without the protocol https://).', array('%default_value' => CONSENT_MANAGER_DEFAULT_CDN)),
    '#default_value' => isset($config['cdn']) ? $config['cdn'] : '',
  );

  $form['consent_manager']['cdn_image'] = array(
    '#type' => 'html_tag',
    '#tag' => 'img',
    '#attributes' => array(
      'src' => $path . '/images/cmpcdn.png',
      'width' => '500',
      'height' => 'auto',
    ),
  );
  
  $form['consent_manager']['custom_code'] = array(
    '#type' => 'textarea',
    '#title' => t('Custom HTML code'),
    '#description' => t('Additional HTML code: appears before the consent manager integration markup.'),
    '#default_value' =>  isset($config['custom_code']) ? $config['custom_code'] : '',
  );

  return system_settings_form($form);
}

/**
 * Consent Manager settings form validation.
 *
 * @param $form
 * @param $form_state
 */
function consent_manager_settings_validate($form, &$form_state) {
  $host = $form_state['values']['consent_manager']['host'];
  if ($host && !filter_var($host, FILTER_VALIDATE_DOMAIN, FILTER_FLAG_HOSTNAME)) {
    form_set_error('consent_manager][host', t('Wrong host value.'));
  }

  $cdn = $form_state['values']['consent_manager']['cdn'];
  if ($cdn && !filter_var($cdn, FILTER_VALIDATE_DOMAIN, FILTER_FLAG_HOSTNAME)) {
    form_set_error('consent_manager][cdn', t('Wrong CDN value.'));
  }
}
